@@ -16,24 +16,33 @@ def _get_kwargs(
     inline_labels: Union[Unset, None, bool] = True,
     inline_label_ids: Union[Unset, None, bool] = True,
     inline_text: Union[Unset, None, bool] = True,
+    debug: Union[Unset, None, bool] = False,
+    parallelize: Union[Unset, None, bool] = False,
 ) -> Dict[str, Any]:
     url = "{}/projects/{projectName}/plans/{planName}/_annotate_format_text".format(
         client.base_url, projectName=project_name, planName=plan_name
     )
 
-    headers: Dict[str, Any] = client.get_headers()
+    headers: Dict[str, str] = client.get_headers()
     cookies: Dict[str, Any] = client.get_cookies()
 
-    params: Dict[str, Any] = {
-        "inlineLabels": inline_labels,
-        "inlineLabelIds": inline_label_ids,
-        "inlineText": inline_text,
-    }
+    params: Dict[str, Any] = {}
+    params["inlineLabels"] = inline_labels
+
+    params["inlineLabelIds"] = inline_label_ids
+
+    params["inlineText"] = inline_text
+
+    params["debug"] = debug
+
+    params["parallelize"] = parallelize
+
     params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
     headers.update({"Content-Type": "text/plain"})
 
     return {
+        "method": "post",
         "url": url,
         "headers": headers,
         "cookies": cookies,
@@ -45,7 +54,7 @@ def _get_kwargs(
 
 def _parse_response(*, response: httpx.Response) -> Optional[File]:
     if response.status_code == 200:
-        response_200 = File(payload=BytesIO(response.content))
+        response_200 = File(payload=BytesIO(response.json()))
 
         return response_200
     return None
@@ -69,7 +78,24 @@ def sync_detailed(
     inline_labels: Union[Unset, None, bool] = True,
     inline_label_ids: Union[Unset, None, bool] = True,
     inline_text: Union[Unset, None, bool] = True,
+    debug: Union[Unset, None, bool] = False,
+    parallelize: Union[Unset, None, bool] = False,
 ) -> Response[File]:
+    """annotate a text with multiple annotators and return a formatted result
+
+    Args:
+        project_name (str):
+        plan_name (str):
+        inline_labels (Union[Unset, None, bool]):  Default: True.
+        inline_label_ids (Union[Unset, None, bool]):  Default: True.
+        inline_text (Union[Unset, None, bool]):  Default: True.
+        debug (Union[Unset, None, bool]):
+        parallelize (Union[Unset, None, bool]):
+
+    Returns:
+        Response[File]
+    """
+
     kwargs = _get_kwargs(
         project_name=project_name,
         plan_name=plan_name,
@@ -78,9 +104,11 @@ def sync_detailed(
         inline_labels=inline_labels,
         inline_label_ids=inline_label_ids,
         inline_text=inline_text,
+        debug=debug,
+        parallelize=parallelize,
     )
 
-    response = httpx.post(
+    response = httpx.request(
         verify=client.verify_ssl,
         **kwargs,
     )
@@ -97,8 +125,23 @@ def sync(
     inline_labels: Union[Unset, None, bool] = True,
     inline_label_ids: Union[Unset, None, bool] = True,
     inline_text: Union[Unset, None, bool] = True,
+    debug: Union[Unset, None, bool] = False,
+    parallelize: Union[Unset, None, bool] = False,
 ) -> Optional[File]:
-    """ """
+    """annotate a text with multiple annotators and return a formatted result
+
+    Args:
+        project_name (str):
+        plan_name (str):
+        inline_labels (Union[Unset, None, bool]):  Default: True.
+        inline_label_ids (Union[Unset, None, bool]):  Default: True.
+        inline_text (Union[Unset, None, bool]):  Default: True.
+        debug (Union[Unset, None, bool]):
+        parallelize (Union[Unset, None, bool]):
+
+    Returns:
+        Response[File]
+    """
 
     return sync_detailed(
         project_name=project_name,
@@ -108,6 +151,8 @@ def sync(
         inline_labels=inline_labels,
         inline_label_ids=inline_label_ids,
         inline_text=inline_text,
+        debug=debug,
+        parallelize=parallelize,
     ).parsed
 
 
@@ -120,7 +165,24 @@ async def asyncio_detailed(
     inline_labels: Union[Unset, None, bool] = True,
     inline_label_ids: Union[Unset, None, bool] = True,
     inline_text: Union[Unset, None, bool] = True,
+    debug: Union[Unset, None, bool] = False,
+    parallelize: Union[Unset, None, bool] = False,
 ) -> Response[File]:
+    """annotate a text with multiple annotators and return a formatted result
+
+    Args:
+        project_name (str):
+        plan_name (str):
+        inline_labels (Union[Unset, None, bool]):  Default: True.
+        inline_label_ids (Union[Unset, None, bool]):  Default: True.
+        inline_text (Union[Unset, None, bool]):  Default: True.
+        debug (Union[Unset, None, bool]):
+        parallelize (Union[Unset, None, bool]):
+
+    Returns:
+        Response[File]
+    """
+
     kwargs = _get_kwargs(
         project_name=project_name,
         plan_name=plan_name,
@@ -129,10 +191,12 @@ async def asyncio_detailed(
         inline_labels=inline_labels,
         inline_label_ids=inline_label_ids,
         inline_text=inline_text,
+        debug=debug,
+        parallelize=parallelize,
     )
 
     async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
-        response = await _client.post(**kwargs)
+        response = await _client.request(**kwargs)
 
     return _build_response(response=response)
 
@@ -146,8 +210,23 @@ async def asyncio(
     inline_labels: Union[Unset, None, bool] = True,
     inline_label_ids: Union[Unset, None, bool] = True,
     inline_text: Union[Unset, None, bool] = True,
+    debug: Union[Unset, None, bool] = False,
+    parallelize: Union[Unset, None, bool] = False,
 ) -> Optional[File]:
-    """ """
+    """annotate a text with multiple annotators and return a formatted result
+
+    Args:
+        project_name (str):
+        plan_name (str):
+        inline_labels (Union[Unset, None, bool]):  Default: True.
+        inline_label_ids (Union[Unset, None, bool]):  Default: True.
+        inline_text (Union[Unset, None, bool]):  Default: True.
+        debug (Union[Unset, None, bool]):
+        parallelize (Union[Unset, None, bool]):
+
+    Returns:
+        Response[File]
+    """
 
     return (
         await asyncio_detailed(
@@ -158,5 +237,7 @@ async def asyncio(
             inline_labels=inline_labels,
             inline_label_ids=inline_label_ids,
             inline_text=inline_text,
+            debug=debug,
+            parallelize=parallelize,
         )
     ).parsed
