@@ -15,24 +15,34 @@ def _get_kwargs(
     inline_labels: Union[Unset, None, bool] = True,
     inline_label_ids: Union[Unset, None, bool] = True,
     inline_text: Union[Unset, None, bool] = True,
+    debug: Union[Unset, None, bool] = False,
+    parallelize: Union[Unset, None, bool] = False,
     output_fields: Union[Unset, None, str] = UNSET,
 ) -> Dict[str, Any]:
     url = "{}/projects/{projectName}/_annotate".format(client.base_url, projectName=project_name)
 
-    headers: Dict[str, Any] = client.get_headers()
+    headers: Dict[str, str] = client.get_headers()
     cookies: Dict[str, Any] = client.get_cookies()
 
-    params: Dict[str, Any] = {
-        "inlineLabels": inline_labels,
-        "inlineLabelIds": inline_label_ids,
-        "inlineText": inline_text,
-        "outputFields": output_fields,
-    }
+    params: Dict[str, Any] = {}
+    params["inlineLabels"] = inline_labels
+
+    params["inlineLabelIds"] = inline_label_ids
+
+    params["inlineText"] = inline_text
+
+    params["debug"] = debug
+
+    params["parallelize"] = parallelize
+
+    params["outputFields"] = output_fields
+
     params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
     headers.update({"Content-Type": "text/plain"})
 
     return {
+        "method": "post",
         "url": url,
         "headers": headers,
         "cookies": cookies,
@@ -67,8 +77,25 @@ def sync_detailed(
     inline_labels: Union[Unset, None, bool] = True,
     inline_label_ids: Union[Unset, None, bool] = True,
     inline_text: Union[Unset, None, bool] = True,
+    debug: Union[Unset, None, bool] = False,
+    parallelize: Union[Unset, None, bool] = False,
     output_fields: Union[Unset, None, str] = UNSET,
 ) -> Response[AnnotatedDocument]:
+    """Annotate text with the last model of the Sherpa suggester
+
+    Args:
+        project_name (str):
+        inline_labels (Union[Unset, None, bool]):  Default: True.
+        inline_label_ids (Union[Unset, None, bool]):  Default: True.
+        inline_text (Union[Unset, None, bool]):  Default: True.
+        debug (Union[Unset, None, bool]):
+        parallelize (Union[Unset, None, bool]):
+        output_fields (Union[Unset, None, str]):
+
+    Returns:
+        Response[AnnotatedDocument]
+    """
+
     kwargs = _get_kwargs(
         project_name=project_name,
         client=client,
@@ -76,10 +103,12 @@ def sync_detailed(
         inline_labels=inline_labels,
         inline_label_ids=inline_label_ids,
         inline_text=inline_text,
+        debug=debug,
+        parallelize=parallelize,
         output_fields=output_fields,
     )
 
-    response = httpx.post(
+    response = httpx.request(
         verify=client.verify_ssl,
         **kwargs,
     )
@@ -95,9 +124,24 @@ def sync(
     inline_labels: Union[Unset, None, bool] = True,
     inline_label_ids: Union[Unset, None, bool] = True,
     inline_text: Union[Unset, None, bool] = True,
+    debug: Union[Unset, None, bool] = False,
+    parallelize: Union[Unset, None, bool] = False,
     output_fields: Union[Unset, None, str] = UNSET,
 ) -> Optional[AnnotatedDocument]:
-    """ """
+    """Annotate text with the last model of the Sherpa suggester
+
+    Args:
+        project_name (str):
+        inline_labels (Union[Unset, None, bool]):  Default: True.
+        inline_label_ids (Union[Unset, None, bool]):  Default: True.
+        inline_text (Union[Unset, None, bool]):  Default: True.
+        debug (Union[Unset, None, bool]):
+        parallelize (Union[Unset, None, bool]):
+        output_fields (Union[Unset, None, str]):
+
+    Returns:
+        Response[AnnotatedDocument]
+    """
 
     return sync_detailed(
         project_name=project_name,
@@ -106,6 +150,8 @@ def sync(
         inline_labels=inline_labels,
         inline_label_ids=inline_label_ids,
         inline_text=inline_text,
+        debug=debug,
+        parallelize=parallelize,
         output_fields=output_fields,
     ).parsed
 
@@ -118,8 +164,25 @@ async def asyncio_detailed(
     inline_labels: Union[Unset, None, bool] = True,
     inline_label_ids: Union[Unset, None, bool] = True,
     inline_text: Union[Unset, None, bool] = True,
+    debug: Union[Unset, None, bool] = False,
+    parallelize: Union[Unset, None, bool] = False,
     output_fields: Union[Unset, None, str] = UNSET,
 ) -> Response[AnnotatedDocument]:
+    """Annotate text with the last model of the Sherpa suggester
+
+    Args:
+        project_name (str):
+        inline_labels (Union[Unset, None, bool]):  Default: True.
+        inline_label_ids (Union[Unset, None, bool]):  Default: True.
+        inline_text (Union[Unset, None, bool]):  Default: True.
+        debug (Union[Unset, None, bool]):
+        parallelize (Union[Unset, None, bool]):
+        output_fields (Union[Unset, None, str]):
+
+    Returns:
+        Response[AnnotatedDocument]
+    """
+
     kwargs = _get_kwargs(
         project_name=project_name,
         client=client,
@@ -127,11 +190,13 @@ async def asyncio_detailed(
         inline_labels=inline_labels,
         inline_label_ids=inline_label_ids,
         inline_text=inline_text,
+        debug=debug,
+        parallelize=parallelize,
         output_fields=output_fields,
     )
 
     async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
-        response = await _client.post(**kwargs)
+        response = await _client.request(**kwargs)
 
     return _build_response(response=response)
 
@@ -144,9 +209,24 @@ async def asyncio(
     inline_labels: Union[Unset, None, bool] = True,
     inline_label_ids: Union[Unset, None, bool] = True,
     inline_text: Union[Unset, None, bool] = True,
+    debug: Union[Unset, None, bool] = False,
+    parallelize: Union[Unset, None, bool] = False,
     output_fields: Union[Unset, None, str] = UNSET,
 ) -> Optional[AnnotatedDocument]:
-    """ """
+    """Annotate text with the last model of the Sherpa suggester
+
+    Args:
+        project_name (str):
+        inline_labels (Union[Unset, None, bool]):  Default: True.
+        inline_label_ids (Union[Unset, None, bool]):  Default: True.
+        inline_text (Union[Unset, None, bool]):  Default: True.
+        debug (Union[Unset, None, bool]):
+        parallelize (Union[Unset, None, bool]):
+        output_fields (Union[Unset, None, str]):
+
+    Returns:
+        Response[AnnotatedDocument]
+    """
 
     return (
         await asyncio_detailed(
@@ -156,6 +236,8 @@ async def asyncio(
             inline_labels=inline_labels,
             inline_label_ids=inline_label_ids,
             inline_text=inline_text,
+            debug=debug,
+            parallelize=parallelize,
             output_fields=output_fields,
         )
     ).parsed
