@@ -12,10 +12,11 @@ def _get_kwargs(
 ) -> Dict[str, Any]:
     url = "{}/auth/logout".format(client.base_url)
 
-    headers: Dict[str, Any] = client.get_headers()
+    headers: Dict[str, str] = client.get_headers()
     cookies: Dict[str, Any] = client.get_cookies()
 
     return {
+        "method": "post",
         "url": url,
         "headers": headers,
         "cookies": cookies,
@@ -36,11 +37,17 @@ def sync_detailed(
     *,
     client: Client,
 ) -> Response[Any]:
+    """Logout
+
+    Returns:
+        Response[Any]
+    """
+
     kwargs = _get_kwargs(
         client=client,
     )
 
-    response = httpx.post(
+    response = httpx.request(
         verify=client.verify_ssl,
         **kwargs,
     )
@@ -52,11 +59,17 @@ async def asyncio_detailed(
     *,
     client: Client,
 ) -> Response[Any]:
+    """Logout
+
+    Returns:
+        Response[Any]
+    """
+
     kwargs = _get_kwargs(
         client=client,
     )
 
     async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
-        response = await _client.post(**kwargs)
+        response = await _client.request(**kwargs)
 
     return _build_response(response=response)
