@@ -9,26 +9,38 @@ T = TypeVar("T", bound="Annotator")
 
 @attr.s(auto_attribs=True)
 class Annotator:
-    """ """
+    """
+    Attributes:
+        engine (str):
+        label (str):
+        name (str):
+        favorite (Union[Unset, bool]):
+        is_default (Union[Unset, bool]):
+    """
 
-    name: str
-    label: str
     engine: str
+    label: str
+    name: str
     favorite: Union[Unset, bool] = UNSET
     is_default: Union[Unset, bool] = UNSET
 
     def to_dict(self) -> Dict[str, Any]:
-        name = self.name
-        label = self.label
         engine = self.engine
+        label = self.label
+        name = self.name
         favorite = self.favorite
         is_default = self.is_default
 
         field_dict: Dict[str, Any] = {}
-        field_dict.update({"name": name, "label": label, "engine": engine})
+        field_dict.update(
+            {
+                "engine": engine,
+                "label": label,
+                "name": name,
+            }
+        )
         if favorite is not UNSET:
             field_dict["favorite"] = favorite
-
         if is_default is not UNSET:
             field_dict["isDefault"] = is_default
 
@@ -37,20 +49,20 @@ class Annotator:
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         d = src_dict.copy()
-        name = d.pop("name")
+        engine = d.pop("engine")
 
         label = d.pop("label")
 
-        engine = d.pop("engine")
+        name = d.pop("name")
 
         favorite = d.pop("favorite", UNSET)
 
         is_default = d.pop("isDefault", UNSET)
 
         annotator = cls(
-            name=name,
-            label=label,
             engine=engine,
+            label=label,
+            name=name,
             favorite=favorite,
             is_default=is_default,
         )
