@@ -7,20 +7,24 @@ T = TypeVar("T", bound="DocSentence")
 
 @attr.s(auto_attribs=True)
 class DocSentence:
-    """ """
+    """
+    Attributes:
+        end (int):
+        start (int):
+    """
 
-    start: int
     end: int
+    start: int
 
     def to_dict(self) -> Dict[str, Any]:
-        start = self.start
         end = self.end
+        start = self.start
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(
             {
-                "start": start,
                 "end": end,
+                "start": start,
             }
         )
 
@@ -29,13 +33,13 @@ class DocSentence:
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         d = src_dict.copy()
-        start = d.pop("start")
-
         end = d.pop("end")
 
+        start = d.pop("start")
+
         doc_sentence = cls(
-            start=start,
             end=end,
+            start=start,
         )
 
         return doc_sentence
