@@ -9,24 +9,29 @@ T = TypeVar("T", bound="DocumentFacets")
 
 @attr.s(auto_attribs=True)
 class DocumentFacets:
-    """ """
+    """
+    Attributes:
+        facets (List[MetadataCount]):
+        metadata (str):
+    """
 
-    metadata: str
     facets: List[MetadataCount]
+    metadata: str
 
     def to_dict(self) -> Dict[str, Any]:
-        metadata = self.metadata
         facets = []
         for facets_item_data in self.facets:
             facets_item = facets_item_data.to_dict()
 
             facets.append(facets_item)
 
+        metadata = self.metadata
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(
             {
-                "metadata": metadata,
                 "facets": facets,
+                "metadata": metadata,
             }
         )
 
@@ -35,8 +40,6 @@ class DocumentFacets:
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         d = src_dict.copy()
-        metadata = d.pop("metadata")
-
         facets = []
         _facets = d.pop("facets")
         for facets_item_data in _facets:
@@ -44,9 +47,11 @@ class DocumentFacets:
 
             facets.append(facets_item)
 
+        metadata = d.pop("metadata")
+
         document_facets = cls(
-            metadata=metadata,
             facets=facets,
+            metadata=metadata,
         )
 
         return document_facets
