@@ -9,24 +9,28 @@ T = TypeVar("T", bound="GroupShare")
 
 @attr.s(auto_attribs=True)
 class GroupShare:
-    """ """
+    """
+    Attributes:
+        can_revoke (bool):
+        group_name (str):
+        mode (ShareMode):
+    """
 
+    can_revoke: bool
     group_name: str
     mode: ShareMode
-    can_revoke: bool
 
     def to_dict(self) -> Dict[str, Any]:
+        can_revoke = self.can_revoke
         group_name = self.group_name
         mode = self.mode.to_dict()
 
-        can_revoke = self.can_revoke
-
         field_dict: Dict[str, Any] = {}
         field_dict.update(
             {
+                "canRevoke": can_revoke,
                 "groupName": group_name,
                 "mode": mode,
-                "canRevoke": can_revoke,
             }
         )
 
@@ -35,16 +39,16 @@ class GroupShare:
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         d = src_dict.copy()
+        can_revoke = d.pop("canRevoke")
+
         group_name = d.pop("groupName")
 
         mode = ShareMode.from_dict(d.pop("mode"))
 
-        can_revoke = d.pop("canRevoke")
-
         group_share = cls(
+            can_revoke=can_revoke,
             group_name=group_name,
             mode=mode,
-            can_revoke=can_revoke,
         )
 
         return group_share
