@@ -7,23 +7,29 @@ T = TypeVar("T", bound="OperationCount")
 
 @attr.s(auto_attribs=True)
 class OperationCount:
-    """Annotation creation response"""
+    """Annotation creation response
 
+    Attributes:
+        count (int): Number of elements affected by the operation
+        operation (str): Name of the operation
+        unit (str): Element unit of the operation
+    """
+
+    count: int
     operation: str
     unit: str
-    count: int
 
     def to_dict(self) -> Dict[str, Any]:
+        count = self.count
         operation = self.operation
         unit = self.unit
-        count = self.count
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(
             {
+                "count": count,
                 "operation": operation,
                 "unit": unit,
-                "count": count,
             }
         )
 
@@ -32,16 +38,16 @@ class OperationCount:
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         d = src_dict.copy()
+        count = d.pop("count")
+
         operation = d.pop("operation")
 
         unit = d.pop("unit")
 
-        count = d.pop("count")
-
         operation_count = cls(
+            count=count,
             operation=operation,
             unit=unit,
-            count=count,
         )
 
         return operation_count
