@@ -9,27 +9,34 @@ T = TypeVar("T", bound="QualityFigures")
 
 @attr.s(auto_attribs=True)
 class QualityFigures:
-    """ """
+    """
+    Attributes:
+        f1 (float):
+        precision (float):
+        recall (float):
+        support (int):
+        roc_auc (Union[Unset, float]):
+    """
 
+    f1: float
     precision: float
     recall: float
-    f1: float
     support: int
     roc_auc: Union[Unset, float] = UNSET
 
     def to_dict(self) -> Dict[str, Any]:
+        f1 = self.f1
         precision = self.precision
         recall = self.recall
-        f1 = self.f1
         support = self.support
         roc_auc = self.roc_auc
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(
             {
+                "f1": f1,
                 "precision": precision,
                 "recall": recall,
-                "f1": f1,
                 "support": support,
             }
         )
@@ -41,20 +48,20 @@ class QualityFigures:
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         d = src_dict.copy()
+        f1 = d.pop("f1")
+
         precision = d.pop("precision")
 
         recall = d.pop("recall")
 
-        f1 = d.pop("f1")
-
         support = d.pop("support")
 
         roc_auc = d.pop("roc_auc", UNSET)
 
         quality_figures = cls(
+            f1=f1,
             precision=precision,
             recall=recall,
-            f1=f1,
             support=support,
             roc_auc=roc_auc,
         )
