@@ -9,22 +9,27 @@ T = TypeVar("T", bound="SegmentHit")
 
 @attr.s(auto_attribs=True)
 class SegmentHit:
-    """ """
+    """
+    Attributes:
+        id (str):
+        score (float):
+        segment (Segment):
+    """
 
-    score: float
     id: str
+    score: float
     segment: Segment
 
     def to_dict(self) -> Dict[str, Any]:
-        score = self.score
         id = self.id
+        score = self.score
         segment = self.segment.to_dict()
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(
             {
-                "score": score,
                 "_id": id,
+                "score": score,
                 "segment": segment,
             }
         )
@@ -34,15 +39,15 @@ class SegmentHit:
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         d = src_dict.copy()
-        score = d.pop("score")
-
         id = d.pop("_id")
 
+        score = d.pop("score")
+
         segment = Segment.from_dict(d.pop("segment"))
 
         segment_hit = cls(
-            score=score,
             id=id,
+            score=score,
             segment=segment,
         )
 
